@@ -10,16 +10,18 @@
 #   anyone's safety, is implied in this software or documentation.
 #
 #   This specific module is licensed under the Perl Artistic License.
+#   Effective 28 January 2021, the original author and copyright holder, 
+#   Martin Hosken, has given permission to use and redistribute this module 
+#   under the MIT license.
 #
 #=======================================================================
 package PDF::Builder::Basic::PDF::File;
 
 use strict;
 use warnings;
-#no warnings qw[ deprecated recursion uninitialized ];
 
-our $VERSION = '3.021'; # VERSION
-my $LAST_UPDATE = '3.021'; # manually update whenever code is changed
+our $VERSION = '3.023'; # VERSION
+our $LAST_UPDATE = '3.023'; # manually update whenever code is changed
 
 =head1 NAME
 
@@ -985,7 +987,7 @@ sub ship_out {
         my ($objnum, $objgen) = @{$self->{' objects'}{$objind->uid()}}[0..1];
         $fh->printf('%d %d obj ', $objnum, $objgen);
         $objind->outobjdeep($fh, $self);
-        $fh->print(" endobj\n");
+        $fh->print("\nendobj\n");
 
         # Note that we've output this obj, not forgetting to update
         # the cache of what's printed.
@@ -1481,6 +1483,9 @@ sub readxrtr {
 	}
     }
 
+    # did we get to here without managing to set $xmin?
+    $xmin ||= 0;
+
     $tdict->{' loc'} = $xpos;
     $tdict->{' xref'} = $xlist;
     $self->{' maxobj'} = $xmin + 1 if $xmin + 1 > $self->{' maxobj'};
