@@ -5,8 +5,8 @@ use base 'PDF::Builder::Content';
 use strict;
 use warnings;
 
-our $VERSION = '3.021'; # VERSION
-my $LAST_UPDATE = '3.019'; # manually update whenever code is changed
+our $VERSION = '3.023'; # VERSION
+our $LAST_UPDATE = '3.023'; # manually update whenever code is changed
 
 =head1 NAME
 
@@ -639,8 +639,8 @@ B<Options:>
 
 =item -last_align => place
 
-where place is 'left' (default), 'center', or 'right' allows you to specify
-the alignment of the last line output.
+where place is 'left' (default), 'center', or 'right' (may be shortened to
+first letter) allows you to specify the alignment of the last line output.
 
 =back
 
@@ -714,7 +714,14 @@ for paragraph first lines). This setting is ignored for centered text.
 
 C<$choice> is 'justified', 'right', 'center', 'left'; the default is 'left'.
 See C<text_justified> call for options to control how a line is expanded or
-condensed if C<$choice> is 'justified'.
+condensed if C<$choice> is 'justified'. C<$choice> may be shortened to the
+first letter.
+
+=item -last_align => place
+
+where place is 'left' (default), 'center', or 'right' (may be shortened to
+first letter) allows you to specify the alignment of the last line output,
+but applies only when C<-align> is 'justified'.
 
 =item -underline => $distance
 
@@ -735,11 +742,11 @@ C<$over> is 1 or 0, with the default 1 (spills over the width).
 B<Example:>
 
     $txt->font($font,$fontsize);
-    $txt->lead($lead);
+    $txt->leading($leading);
     $txt->translate($x,$y);
     $overflow = $txt->paragraph( 'long paragraph here ...',
                                  $width,
-                                 $y+$lead-$bottom_margin );
+                                 $y+$leading-$bottom_margin );
 
 B<Note:> if you need to change any text treatment I<within> a paragraph 
 (B<bold> or I<italicized> text, for instance), this can not handle it. Only 
@@ -759,7 +766,7 @@ sub paragraph {
 
     my @line = ();
     my $nwidth = 0;
-    my $lead = $self->lead();
+    my $leading = $self->leading();
     my $align = 'l'; # default left
     if (defined($opts{'-align'})) {
 	if    ($opts{'-align'} =~ /^l/i) { $align = 'l'; }
@@ -783,7 +790,7 @@ sub paragraph {
 	if ($indent < 0 && !$first_line) { $lw += $indent*$em; }
 	# now, need to indent (move line start) right for 'l' and 'j'
 	if ($lw < $width && ($align eq 'l' || $align eq 'j')) {
-        $self->cr($lead); # go UP one line
+        $self->cr($leading); # go UP one line
 	    $self->nl(88*abs($indent)); # come down to right line and move right
 	}
 
@@ -801,7 +808,7 @@ sub paragraph {
 	$first_line = 0;
 
 	# bail out and just return remaining $text if run out of vertical space
-        last if ($height -= $lead) < 0;
+        last if ($height -= $leading) < 0;
     }
 
     if (wantarray) {
@@ -833,6 +840,9 @@ C<$continue> is 0 for the first call of section(), and then use the value
 returned from the previous call (1 if a paragraph was cut in the middle) to 
 prevent unwanted indenting or outdenting of the first line being printed.
 
+For compatibility with recent changes to PDF::API2, B<paragraphs> is accepted
+as an I<alias> for C<section>.
+
 B<Options:>
 
 =over
@@ -850,6 +860,11 @@ See C<paragraph> for other C<%opts> you can use, such as -align and -pndnt.
 
 =cut
 
+# alias for compatibility
+sub paragraphs {
+    return section(@_);
+}
+
 sub section {
     my ($self, $text, $width,$height, $continue, %opts) = @_;
 
