@@ -3,8 +3,8 @@ package PDF::Builder::Docs;
 use strict;
 use warnings;
 
-our $VERSION = '3.021'; # VERSION
-my $LAST_UPDATE = '3.020'; # manually update whenever code is changed
+our $VERSION = '3.023'; # VERSION
+our $LAST_UPDATE = '3.023'; # manually update whenever code is changed
 
 # originally part of Builder.pm, it was split out due to its length
 
@@ -520,6 +520,15 @@ PDF::API2 should be convertible to PDF::Builder simply by changing "API2"
 anywhere it occurs to "Builder". See the INFO/KNOWN_INCOMP known 
 incompatibilities file for further information.
 
+=head3 Thanks...
+
+Many users have helped out by reporting bugs and requesting enhancements. A
+special shout out goes to those who have contributed code and tests, or
+coordinated their package development with the needs of PDF::Builder:
+Ben Bullock, Cary Gravel, Gregor Herrmann, Petr Pisar, Jeffrey Ratcliffe,
+Steve Simms (via PDF::API2 fixes), and Johan Vromans.
+Drop me a line if I've overlooked your contribution!
+
 =head1 DETAILED NOTES ON METHODS
 
 =head2 After saving a file...
@@ -1608,11 +1617,6 @@ Valid %options are:
 Character width condense/expand factor (0.1-0.9 = condense, 1 = normal/default, 
 1.1+ = expand). It is the multiplier to apply to the width of each character.
 
-=item -slant
-
-B<DEPRECATED>. It is the old name for C<-condense>, and will eventually be
-removed. Use C<-condense> instead.
-
 =item -oblique
 
 Italic angle (+/- degrees, default 0), sets B<skew> of character box.
