@@ -6,8 +6,8 @@ use strict;
 use warnings;
 #no warnings qw[ recursion uninitialized ];
 
-our $VERSION = '3.021'; # VERSION
-my $LAST_UPDATE = '3.021'; # manually update whenever code is changed
+our $VERSION = '3.023'; # VERSION
+our $LAST_UPDATE = '3.021'; # manually update whenever code is changed
 
 use Carp;
 use Encode qw(:all);
